pub struct ExactnessNote {
pub entity: Exactness,
pub fields: BTreeMap<String, Exactness>,
}Expand description
Exactness for an entity and sparse overrides for its serialized fields.
Fields
entity: ExactnessExactness of the entity except where overridden by fields.
fields: BTreeMap<String, Exactness>Exactness overrides keyed by serde field path.