pub enum DecodeMode {
Strict,
Salvage,
}Expand description
Whether a successful decode may report mandatory transfer losses.
Variants
Strict
Reject a completed decode that reports a mandatory transfer loss.
Salvage
Return the decoded result with its loss report.