pub enum ChamferSpec {
Unresolved {
form: Option<ChamferForm>,
},
Distance {
distance: Length,
},
TwoDistances {
first: Length,
second: Length,
},
DistanceAngle {
distance: Length,
angle: Angle,
},
}Expand description
Dimensional definition of an edge chamfer.
Variants
Unresolved
Dimensional specification is retained but not fully resolved.
Fields

form: Option<ChamferForm>Structural specification form, when independently identified.
Distance
Equal setback distance on both faces meeting the edge.
TwoDistances
Independent setback distances on each face meeting the edge.
Fields
DistanceAngle
A setback distance on one face plus an angle from it to the other.