pub enum CoilExtent {
RevolutionsHeight {
revolutions: f64,
height: Length,
},
RevolutionsPitch {
revolutions: f64,
pitch: Length,
},
HeightPitch {
height: Length,
pitch: Length,
},
Spiral {
revolutions: f64,
radial_pitch: Length,
},
}Expand description
Independent driving dimensions of a Coil trajectory.
Variants
RevolutionsHeight
Axial coil driven by revolution count and total signed height.
RevolutionsPitch
Axial coil driven by revolution count and signed pitch per revolution.
Fields
HeightPitch
Axial coil driven by total signed height and signed pitch per revolution.
Spiral
Planar spiral driven by revolution count and signed radial pitch.