pub struct ConfigurationId(pub String);Expand description
Identifies a neutral design configuration.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ConfigurationId
impl Clone for ConfigurationId
Sourcefn clone(&self) -> ConfigurationId
fn clone(&self) -> ConfigurationId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigurationId
impl Debug for ConfigurationId
Sourceimpl<'de> Deserialize<'de> for ConfigurationId
impl<'de> Deserialize<'de> for ConfigurationId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigurationId
Sourceimpl Hash for ConfigurationId
impl Hash for ConfigurationId
Sourceimpl JsonSchema for ConfigurationId
impl JsonSchema for ConfigurationId
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ConfigurationId
impl Ord for ConfigurationId
Sourcefn cmp(&self, other: &ConfigurationId) -> Ordering
fn cmp(&self, other: &ConfigurationId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ConfigurationId
impl PartialEq for ConfigurationId
Sourceimpl PartialOrd for ConfigurationId
impl PartialOrd for ConfigurationId
Sourceimpl Serialize for ConfigurationId
impl Serialize for ConfigurationId
impl StructuralPartialEq for ConfigurationId