pub struct SpreadsheetId(pub String);Expand description
Stable spreadsheet identity.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for SpreadsheetId
impl Clone for SpreadsheetId
Sourcefn clone(&self) -> SpreadsheetId
fn clone(&self) -> SpreadsheetId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpreadsheetId
impl Debug for SpreadsheetId
Sourceimpl<'de> Deserialize<'de> for SpreadsheetId
impl<'de> Deserialize<'de> for SpreadsheetId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SpreadsheetId
Sourceimpl Hash for SpreadsheetId
impl Hash for SpreadsheetId
Sourceimpl JsonSchema for SpreadsheetId
impl JsonSchema for SpreadsheetId
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for SpreadsheetId
impl Ord for SpreadsheetId
Sourcefn cmp(&self, other: &SpreadsheetId) -> Ordering
fn cmp(&self, other: &SpreadsheetId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SpreadsheetId
impl PartialEq for SpreadsheetId
Sourceimpl PartialOrd for SpreadsheetId
impl PartialOrd for SpreadsheetId
Sourceimpl Serialize for SpreadsheetId
impl Serialize for SpreadsheetId
impl StructuralPartialEq for SpreadsheetId