pub enum PatternKind {
Unresolved {
form: Option<PatternForm>,
},
Linear {
direction: Option<Vector3>,
spacing: Length,
count: u32,
second: Option<LinearPatternDirection>,
},
LinearOffsets {
direction: Option<Vector3>,
offsets: Vec<Length>,
},
Circular {
axis_origin: Point3,
axis_dir: Vector3,
angle: Angle,
count: u32,
},
CircularAngles {
axis_origin: Point3,
axis_dir: Vector3,
angles: Vec<Angle>,
},
CurveDriven {
path: Option<PathRef>,
spacing: Length,
count: u32,
},
Mirror {
plane_origin: Point3,
plane_normal: Vector3,
},
Scale {
center: PatternScaleCenter,
final_factor: f64,
count: u32,
},
Composite {
stages: Vec<PatternStage>,
},
}Expand description
Spatial transform used to repeat or reflect seed features.
Variants
Unresolved
Pattern construction whose form or required operands are unresolved.
Fields

form: Option<PatternForm>Native pattern form, when identified independently of its operands.
Linear
Repeats seeds evenly along a straight direction.
Fields

second: Option<LinearPatternDirection>Optional complete second translation direction.
LinearOffsets
Repeats seeds at explicitly located distances along a straight direction.
Fields
Circular
Repeats seeds evenly around an axis.
Fields
CircularAngles
Repeats seeds at explicitly located angles around an axis.
Fields
CurveDriven
Repeats seeds at fixed arc-length spacing along a curve.
Fields
Mirror
Reflects seeds across a plane.
Fields
Scale
Repeats seeds using progressive uniform scales.
Fields

center: PatternScaleCenterFixed locus used by every scale transform.
Composite
Applies an ordered sequence of pattern stages.
Fields

stages: Vec<PatternStage>Stages in application order.